/*
This header enables support for the MAGE IR protocol. This code assumes a PIC18F2480 or 2580
is being used with a 20MHz clock for receiving and a PIC16F688 is being used for transmitting.
Also the IR receiver should be a TSOP36256. Some other receivers
may work, but this one has been found to have good range and do a very good job of blocking
noise.

!!! Any hardware changes may affect the performance of the IR protocol.!!!

If IR data becomes inaccurate due to hardware changes, you will most likely need
to adjust timer2. This will affect the timing of the period which is sampled for each bit.

setup_timer_2(T2_DIV_BY_16,141,4); is the original setting using the assumed hardware.

*/



int1 ir_start = 0;
int8 ir_bit[64];
int8 IR_buffer[8];
int8 ir_bit_count = 0;
int1 IR_data_ready = 0;

void decode_IR()
{
   int8 i = 0;
   int8 h = 0;
   int8 index = 0;
   
   for(i=0;i<64;i++)
   {
      if(IR_bit[i] > 2)
      {
         IR_bit[i] = 0;
      }
      else
      {  
         IR_bit[i] = 1;
      }  
   }
   
   for(h = 0; h<8; h++)
   {
       for (i = 0; i < 8; i++)
       {
          IR_buffer[h] = IR_buffer[h]*2 + IR_bit[index+i];
       }
       
       index+=8;
   }
   
   for(i=0;i<64;i++)
   {
      IR_bit[i] = 0;    
   }
}

#int_EXT
void  EXT_isr(void) 
{
   if(ir_start == 0)
   {
      ir_start = 1;
      delay_us(10);
      set_timer2(0);
   }
   
   else
   {
      ir_bit[ir_bit_count]++;
   }
}

#int_TIMER2
void  TIMER2_isr(void) 
{
   
   if(ir_start == 1)
   {
      if(ir_bit_count < 64)
      {
        ir_bit_count++;
      }
      else
      {
         disable_interrupts(INT_TIMER2);
         decode_IR();
         IR_data_ready = 1;
         ir_start = 0;
         ir_bit_count = 0;
         enable_interrupts(INT_TIMER2);
      }
   }
}





